@@ -32,7 +32,7 @@ class CLIContext:
 
 @click.group()
 @click.version_option(__version__)
-@click.option('--config', '-c', type=str, multiple=True, help='Path to dipdup YAML config', default='dipdup.yml')
+@click.option('--config', '-c', type=str, multiple=True, help='Path to dipdup YAML config', default=['dipdup.yml'])
 @click.option('--logging-config', '-l', type=str, help='Path to logging YAML config', default='logging.yml')
 @click.pass_context
 @click_async
@@ -56,12 +56,13 @@ async def cli(ctx, config: List[str], logging_config: str):
 
 
 @cli.command(help='Run existing dipdup project')
+@click.option('--reindex', is_flag=True)
 @click.pass_context
 @click_async
-async def run(ctx) -> None:
+async def run(ctx, reindex: bool) -> None:
     config: DipDupConfig = ctx.obj.config
     dipdup = DipDup(config)
-    await dipdup.run()
+    await dipdup.run(reindex)
 
 
 @cli.command(help='Initialize new dipdup project')
