@@ -6,7 +6,7 @@ from contextlib import suppress
 from os import mkdir
 from os.path import basename, dirname, exists, join, splitext
 from shutil import rmtree
-from typing import Any, Dict
+from typing import Any, Dict, cast
 
 from jinja2 import Template
 
@@ -15,9 +15,12 @@ from dipdup.config import (
     BigMapIndexConfig,
     ContractConfig,
     DipDupConfig,
-    IndexTemplateConfig,
+    DynamicTemplateConfig,
     OperationHandlerConfig,
+    OperationHandlerOriginationPatternConfig,
+    OperationHandlerTransactionPatternConfig,
     OperationIndexConfig,
+    StaticTemplateConfig,
     TzktDatasourceConfig,
 )
 from dipdup.datasources.tzkt.datasource import TzktDatasource
@@ -78,7 +81,18 @@ async def create_package(config: DipDupConfig):
             file.write(models_code)
 
 
-async def fetch_schemas(config: DipDupConfig):
+async def resolve_dynamic_templates(config: DipDupConfig) -> None:
+    for index_name, index_config in config.indexes.items():
+        if isinstance(index_config, DynamicTemplateConfig):
+            config.indexes[index_name] = StaticTemplateConfig(
+                template=index_config.template,
+                values=dict(contract=cast(str, index_config.similar_to)),
+            )
+            config.pre_initialize()
+            index_config = config.indexes[index_name]
+
+
+async def fetch_schemas(config: DipDupConfig) -> None:
     _logger.info('Creating `schemas` package')
     schemas_path = join(config.package_path, 'schemas')
     with suppress(FileExistsError):
@@ -86,11 +100,22 @@ async def fetch_schemas(config: DipDupConfig):
 
     schemas_cache = SchemasCache()
 
-    for index_name, index_config in config.indexes.items():
+    for index_config in config.indexes.values():
+
         if isinstance(index_config, OperationIndexConfig):
             for operation_handler_config in index_config.handlers:
                 for operation_pattern_config in operation_handler_config.pattern:
-                    contract_config = operation_pattern_config.contract_config
+
+                    if (
+                        isinstance(operation_pattern_config, OperationHandlerTransactionPatternConfig)
+                        and operation_pattern_config.entrypoint
+                    ):
+                        contract_config = operation_pattern_config.destination_contract_config
+                    elif isinstance(operation_pattern_config, OperationHandlerOriginationPatternConfig):
+                        contract_config = operation_pattern_config.contract_config
+                    else:
+                        continue
+
                     contract_schemas = await schemas_cache.get(index_config.datasource_config, contract_config)
 
                     contract_schemas_path = join(schemas_path, contract_config.module_name)
@@ -104,6 +129,9 @@ async def fetch_schemas(config: DipDupConfig):
                         with open(storage_schema_path, 'w') as file:
                             file.write(json.dumps(storage_schema, indent=4, sort_keys=True))
 
+                    if not isinstance(operation_pattern_config, OperationHandlerTransactionPatternConfig):
+                        continue
+
                     parameter_schemas_path = join(contract_schemas_path, 'parameter')
                     with suppress(FileExistsError):
                         mkdir(parameter_schemas_path)
@@ -128,8 +156,6 @@ async def fetch_schemas(config: DipDupConfig):
                         with open(entrypoint_schema_path, 'r') as file:
                             existing_schema = json.loads(file.read())
                         if entrypoint_schema != existing_schema:
-                            # FIXME: Different field order counts as different schema
-                            # raise ValueError(f'Contract "{contract.address}" falsely claims to be a "{contract.typename}"')
                             _logger.warning('Contract "%s" falsely claims to be a "%s"', contract_config.address, contract_config.typename)
 
         elif isinstance(index_config, BigMapIndexConfig):
@@ -147,7 +173,12 @@ async def fetch_schemas(config: DipDupConfig):
                     with suppress(FileExistsError):
                         mkdir(big_map_schemas_path)
 
-                    big_map_schema = next(ep for ep in contract_schemas['bigMaps'] if ep['path'] == big_map_pattern_config.path)
+                    try:
+                        big_map_schema = next(ep for ep in contract_schemas['bigMaps'] if ep['path'] == big_map_pattern_config.path)
+                    except StopIteration as e:
+                        raise ConfigurationError(
+                            f'Contract `{contract_config.address}` has no big map path `{big_map_pattern_config.path}`'
+                        ) from e
                     big_map_key_schema = big_map_schema['keySchema']
                     big_map_key_schema_path = join(big_map_schemas_path, f'{big_map_pattern_config.path}.key.json')
 
@@ -162,7 +193,7 @@ async def fetch_schemas(config: DipDupConfig):
                         with open(big_map_value_schema_path, 'w') as file:
                             file.write(json.dumps(big_map_value_schema, indent=4))
 
-        elif isinstance(index_config, IndexTemplateConfig):
+        elif isinstance(index_config, StaticTemplateConfig):
             raise RuntimeError('Config is not initialized')
 
         else:
